@@ -20,8 +20,8 @@ class TaskEngine(Module):
     任务引擎
     """
 
-    def __init__(self, app_id,set):
-        super().__init__(app_id, 'te',set)
+    def __init__(self, app_id, set, init):
+        super().__init__(app_id, 'te', set)
         self.app_id = app_id
         self.sess = Session()
         self.api_server = Config.base_url
@@ -41,6 +41,8 @@ class TaskEngine(Module):
             'X-Appid': self.app_id,
             'X-Userid': Config.user_id
         }
+        if init:
+            self.init()
 
     def load(self, path):
         """
